==> qbs-src-1.4.5.zip: qbs-src-1.4.5/src/lib/corelib/language/itemdeclaration.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "itemdeclaration.h"

namespace qbs {
namespace Internal {

ItemDeclaration::ItemDeclaration(const QString &typeName)
    : m_typeName(typeName)
{
}

ItemDeclaration::ItemDeclaration(const qbs::Internal::ItemDeclaration &other)
    : m_typeName(other.m_typeName)
    , m_properties(other.m_properties)
    , m_allowedChildTypes(other.m_allowedChildTypes)
{
}

ItemDeclaration &ItemDeclaration::operator<<(const PropertyDeclaration &decl)
{
    m_properties.append(decl);
    return *this;
}

bool ItemDeclaration::isChildTypeAllowed(const QString &typeName) const
{
    return m_allowedChildTypes.contains(typeName);
}

} // namespace Internal
} // namespace qbs

==> qbs-src-1.5.0.zip: qbs-src-1.5.0/src/lib/corelib/language/itemdeclaration.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "itemdeclaration.h"

namespace qbs {
namespace Internal {

ItemDeclaration::ItemDeclaration(ItemType type)
    : m_type(type)
{
}

ItemDeclaration::ItemDeclaration(const qbs::Internal::ItemDeclaration &other)
    : m_type(other.m_type)
    , m_properties(other.m_properties)
    , m_allowedChildTypes(other.m_allowedChildTypes)
{
}

ItemDeclaration &ItemDeclaration::operator<<(const PropertyDeclaration &decl)
{
    m_properties.append(decl);
    return *this;
}

bool ItemDeclaration::isChildTypeAllowed(ItemType type) const
{
    if (m_type > ItemType::LastActualItem || type > ItemType::LastActualItem)
        return true;
    return m_allowedChildTypes.contains(type);
}

} // namespace Internal
} // namespace qbs
